@@ -1,6 +1,6 @@
 # PODNAME: Syntax::Highlight::WithEmacs
 
-use Moops;
+package Syntax::Highlight::WithEmacs;
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Syntax::Highlight::WithEmacs - syntax-highlight source code using Emacs
 
 =head1 VERSION
 
-version 0.1
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -94,46 +94,50 @@ nxml-mode as default (on GNU FSF Emacs 23):
 
 =cut
 
-class Syntax::Highlight::WithEmacs 0.2 {
-    use warnings;
-    use File::Temp;
-    use Carp;
-    use XML::LibXML;
-    use CSS::Tiny;
-    use Hash::Util qw(lock_ref_keys_plus);
-    use IPC::Run qw(run);
-    use Term::ANSIColor;
-    my $has_ccoxt; BEGIN { $has_ccoxt = eval q{
-    use Convert::Color::XTerm;
-    1}; }
+use strict;
+use warnings;
 
-    {
-    	no warnings qw(redefine);
-      # fix for FCGI environment
-    	my $ipc_close_terminal = \&IPC::Run::close_terminal;
-    	*::IPC::Run::close_terminal = sub {
-    	    untie *STDIN; untie *STDOUT; untie *STDERR;
-    	    $ipc_close_terminal->(@_);
-    	};
+our $VERSION = '0.3';
+use Moo;
+use File::Temp;
+use Carp;
+use XML::LibXML;
+use CSS::Tiny;
+use Hash::Util qw(lock_ref_keys_plus);
+use IPC::Run qw(run);
+use Term::ANSIColor;
+my $has_ccoxt; BEGIN { $has_ccoxt = eval q{
+use Convert::Color::XTerm;
+1}; }
 
-      # fix for broken controlling terminal in IPC::Run :-{
-	my $ipc_do_kid_n_exit = \&IPC::Run::_do_kid_and_exit;
-	*::IPC::Run::_do_kid_and_exit = sub {
-	    my $that = shift;
-	    eval {
-		if ( %{$that->{PTYS}} ) {
-		    for ( keys %{$that->{PTYS}} ) {
-			unless (${*{$that->{PTYS}->{$_}}}{_slave_controller}++) {
-			    IPC::Run::Debug::_debug("Making a controller of ptty '$_'")
-				    if IPC::Run::Debug::_debugging_details;
-			    $that->{PTYS}->{$_}->make_slave_controlling_terminal;
-			};
-		    }
-		}
-	    };
-	    $ipc_do_kid_n_exit->($that => @_);
-	};
-    }
+{
+    no warnings qw(redefine);
+    # fix for FCGI environment
+    my $ipc_close_terminal = \&IPC::Run::close_terminal;
+    *::IPC::Run::close_terminal = sub {
+	untie *STDIN; untie *STDOUT; untie *STDERR;
+	$ipc_close_terminal->(@_);
+    };
+
+#     # fix for broken controlling terminal in IPC::Run :-{
+#     my $ipc_do_kid_n_exit = \&IPC::Run::_do_kid_and_exit;
+#     *::IPC::Run::_do_kid_and_exit = sub {
+# 	my $that = shift;
+# 	eval {
+# 	    if ( %{$that->{PTYS}} ) {
+# 		for ( keys %{$that->{PTYS}} ) {
+# 		    unless (${*{$that->{PTYS}->{$_}}}{_slave_controller}++) {
+# 			IPC::Run::Debug::_debug("Making a controller of ptty '$_'")
+# 				if IPC::Run::Debug::_debugging_details;
+# 			$that->{PTYS}->{$_}->make_slave_controlling_terminal;
+# 		    }
+# 		    ;
+# 		}
+# 	    }
+# 	};
+# 	$ipc_do_kid_n_exit->($that => @_);
+#     };
+}
 
 =head1 METHODS
 
@@ -214,68 +218,75 @@ C<ansify_string> method.
 
 =cut
 
-    my $servercnt = 0;
-    has mode	     => (is => 'rw', default => 'font');
-    has htmlize_generate_hyperlinks
-	             => (is => 'rw', default => 0);
-    has use_client   => (is => 'ro', default => 1);
-    has server_name  => (is => 'ro', default => sub { ++$servercnt; "EmacsHtmlize$$\_$servercnt" });
-    has start_server => (is => 'ro', default => 1, reader => '_start_server');
-    has kill_server  => (is => 'ro', default => 1, reader => '_kill_server');
-    has term_spec    => (is => 'ro', default => 'xterm-256color');
-    has emacs_args   => (is => 'rw', default => sub{[]});
-    has emacs_cmd    => (is => 'ro', default => 'emacs');
-    has client_cmd   => (is => 'ro', default => 'emacsclient');
-    has ansi_opts    => (is => 'rw', default => sub{+{}});
+my $servercnt = 0;
+has mode	     => (is => 'rw', default => 'font');
+has htmlize_generate_hyperlinks
+    => (is => 'rw', default => 0);
+has use_client   => (is => 'ro', default => 1);
+has server_name  => (is => 'ro', default => sub { ++$servercnt; "EmacsHtmlize$$\_$servercnt" });
+has start_server => (is => 'ro', default => 1, reader => '_start_server');
+has kill_server  => (is => 'ro', default => 1, reader => '_kill_server');
+has term_spec    => (is => 'ro', default => 'xterm-256color');
+has emacs_args   => (is => 'rw', default => sub{[]});
+has emacs_cmd    => (is => 'ro', default => 'emacs');
+has client_cmd   => (is => 'ro', default => 'emacsclient');
+has ansi_opts    => (is => 'rw', default => sub{+{}});
 
-    method BUILD {
-	$self->{lx} = XML::LibXML->new;
-	$self->{lx}->recover(2);
-	lock_ref_keys_plus($self,
-			   # client module:
-			   'made_server',
-			   # ansify module:
-			   'ansify_css', 'ansify_ccss', 'ansify_opts', '_ansify_italic'
-			  );
-	$self->start_server if $self->_start_server && $self->use_client;
-    }
+sub BUILD {
+    my ($self, $args) = @_;
+    $self->{lx} = XML::LibXML->new;
+    $self->{lx}->recover(2);
+    lock_ref_keys_plus($self,
+		       # client module:
+		       'made_server',
+		       # ansify module:
+		       'ansify_css', 'ansify_ccss', 'ansify_opts', '_ansify_italic'
+		      );
+    $self->start_server if $self->_start_server && $self->use_client;
+}
 
-    method start_server {
-	return if $self->{made_server};
-	my ($cout, $cin, $cerr);
-	my @cmd = ($self->emacs_cmd, @{$self->emacs_args},
-		   '--daemon' . ($self->server_name ? '='.$self->server_name : ''));
-	local $ENV{HOME} = (getpwuid $<)[7] unless $ENV{HOME};
-	local $ENV{TERM} = $self->term_spec;
-	run \@cmd, \$cin, \$cout, \$cerr;
-	$self->{made_server} = 1;
-    }
+sub start_server {
+    my $self = shift;
+    return if $self->{made_server};
+    my ($cout, $cin, $cerr);
+    my @cmd = ($self->emacs_cmd, @{$self->emacs_args},
+	       '--daemon' . ($self->server_name ? '='.$self->server_name : ''));
+    local $ENV{HOME} = (getpwuid $<)[7] unless $ENV{HOME};
+    local $ENV{TERM} = $self->term_spec;
+    run \@cmd, \$cin, \$cout, \$cerr;
+    $self->{made_server} = 1;
+}
 
-    method _client_cmd_args {
-	($self->client_cmd, -a => '', ($self->server_name ? (-s => $self->server_name) : ()))
-    }
+sub _client_cmd_args {
+    my $self = shift;
+    ($self->client_cmd, -a => '', ($self->server_name ? (-s => $self->server_name) : ()))
+}
 
-    method run_htmlize($in, $out) {
-	my $mode = $self->mode;
-	for ($in, $out) {
-	    unless (defined) { $_ = ''; next; }
-	    s/(["\\])/\\$1/g;
-	    $_ = qq{"$_"};
+sub run_htmlize {
+    my $self = shift;
+    my ($in, $out) = @_;
+    my $mode = $self->mode;
+    for ($in, $out) {
+	unless (defined) {
+	    $_ = ''; next;
 	}
-	my $kill_command = $self->use_client ? '(delete-frame (selected-frame) t)' : '(kill-emacs)';
-	my @cmd = $self->use_client ? $self->_client_cmd_args : $self->emacs_cmd;
-	my @cmd_args = @{$self->emacs_args};
-	@cmd_args = grep { !/^-q$/i } @cmd_args if $self->use_client;
-	my $hyper = $self->htmlize_generate_hyperlinks ? 't' : 'nil';
-	my @args = (@cmd, '-nw', @cmd_args,
-		    -eval => qq((ignore-errors (require 'htmlize) (setq htmlize-generate-hyperlinks $hyper) (setq htmlize-output-type "$mode") (htmlize-file $in $out))),
-		    -eval => $kill_command);
-	local $ENV{HOME} = (getpwuid $<)[7] unless $ENV{HOME};
-	local $ENV{TERM} = $self->term_spec;
-	my ($tin, $tout, $err);
-	run \@args, '<pty<', \$tin, '>pty>', \$tout, '2>', \$err;
-	$self->{made_server} = $self->use_client;
+	s/(["\\])/\\$1/g;
+	$_ = qq{"$_"};
     }
+    my $kill_command = $self->use_client ? '(delete-frame (selected-frame) t)' : '(kill-emacs)';
+    my @cmd = $self->use_client ? $self->_client_cmd_args : $self->emacs_cmd;
+    my @cmd_args = @{$self->emacs_args};
+    @cmd_args = grep { !/^-q$/i } @cmd_args if $self->use_client;
+    my $hyper = $self->htmlize_generate_hyperlinks ? 't' : 'nil';
+    my @args = (@cmd, '-nw', @cmd_args,
+		-eval => qq((ignore-errors (require 'htmlize) (setq htmlize-generate-hyperlinks $hyper) (setq htmlize-output-type "$mode") (htmlize-file $in $out))),
+		-eval => $kill_command);
+    local $ENV{HOME} = (getpwuid $<)[7] unless $ENV{HOME};
+    local $ENV{TERM} = $self->term_spec;
+    my ($tin, $tout, $err);
+    run \@args, '<pty<', \$tin, '>pty>', \$tout, '2>', \$err;
+    $self->{made_server} = $self->use_client;
+}
 
 =head2 htmlize_file
 
@@ -303,9 +314,11 @@ HTML file with any tool you like.
 
 =cut
 
-    method htmlize_file($file, $out = undef) {
-	$self->run_htmlize($file, $out);
-    }
+sub htmlize_file {
+    my $self = shift;
+    my ($file, $out) = @_;
+    $self->run_htmlize($file, $out);
+}
 
 =head2 htmlize_string
 
@@ -335,36 +348,38 @@ context, only the HTML node is returned.
 
 =cut
 
-    method htmlize_string($string, $mode) {
-	my $fh = File::Temp->new( TEMPLATE => 'EmacsHtmlize'.$$.'XXXXX', SUFFIX => ".$mode" );
-	binmode $fh, ':utf8';
-	print $fh $string;
-	$fh->flush;
-	my $filename = $fh->filename;
-	my $no_unlink = -f "$filename.html";
-	$self->htmlize_file($filename);
-	unless (-f "$filename.html") {
-	    croak "failed to create result file $filename.html";
-	}
-	my $doc = $self->{lx}->load_html(location => "$filename.html", encoding => 'UTF-8');
-	unlink "$filename.html" unless $no_unlink;
-	my ($html, $css) = ($doc->findnodes('/html/body/pre'), $doc->findnodes('/html/head/style'));
-	if ($css) {
-	    my $raw = $css->findvalue('.');
-	    $raw =~ s/^\s*<!--(.*)-->\s*$/$1/s;
-	    $css = CSS::Tiny->read_string($raw);
-	    delete $css->{a};
-	    delete $css->{'a:hover'};
-	    $css->{pre} = delete $css->{body};
-	}
-	{
-	    my $ch_fixup = $html->firstChild if $html;
-	    $ch_fixup->replaceDataRegEx("^\n", '')
-		if $ch_fixup && $ch_fixup->isa('XML::LibXML::Text');
-	}
-	$html->normalize;
-	wantarray ? ($html, $css ? $css : ()) : $html
+sub htmlize_string {
+    my $self = shift;
+    my ($string, $mode) = @_;
+    my $fh = File::Temp->new( TEMPLATE => 'EmacsHtmlize'.$$.'XXXXX', SUFFIX => ".$mode" );
+    binmode $fh, ':utf8';
+    print $fh $string;
+    $fh->flush;
+    my $filename = $fh->filename;
+    my $no_unlink = -f "$filename.html";
+    $self->htmlize_file($filename);
+    unless (-f "$filename.html") {
+	croak "failed to create result file $filename.html";
     }
+    my $doc = $self->{lx}->load_html(location => "$filename.html", encoding => 'UTF-8');
+    unlink "$filename.html" unless $no_unlink;
+    my ($html, $css) = ($doc->findnodes('/html/body/pre'), $doc->findnodes('/html/head/style'));
+    if ($css) {
+	my $raw = $css->findvalue('.');
+	$raw =~ s/^\s*<!--(.*)-->\s*$/$1/s;
+	$css = CSS::Tiny->read_string($raw);
+	delete $css->{a};
+	delete $css->{'a:hover'};
+	$css->{pre} = delete $css->{body};
+    }
+    {
+	my $ch_fixup = $html->firstChild if $html;
+	$ch_fixup->replaceDataRegEx("^\n", '')
+	    if $ch_fixup && $ch_fixup->isa('XML::LibXML::Text');
+    }
+    $html->normalize;
+    wantarray ? ($html, $css ? $css : ()) : $html
+}
 
 =head2 ansify_string
 
@@ -464,130 +479,139 @@ and returns the control codes for the requested colour spec
 
 =cut
 
-    my %ansi_default_opts;
-    BEGIN {
-	%ansi_default_opts = (
-	    italic_as => 'reverse',
-	    css => undef,
-	    color_depth => 2**24,
-	    color_format => 'aix',
-	   );
+my %ansi_default_opts;
+BEGIN {
+    %ansi_default_opts = (
+	italic_as => 'reverse',
+	css => undef,
+	color_depth => 2**24,
+	color_format => 'aix',
+       );
+}
+sub _colour_to_ansi {
+    my $self = shift;
+    my ($ct, $r, $g, $b) = @_;
+    my $cd = $self->{ansify_opts}{color_depth};
+    if (!$has_ccoxt && $cd < 2**24 && $cd >= 8) {
+	croak "module Convert::Color::XTerm is required for color_depth $cd";
     }
-    method _colour_to_ansi($ct, $r, $g, $b) {
-	my $cd = $self->{ansify_opts}{color_depth};
-	if (!$has_ccoxt && $cd < 2**24 && $cd >= 8) {
-	    croak "module Convert::Color::XTerm is required for color_depth $cd";
-	}
-	my $bg = $ct =~ /background/;
-	my @cv;
-	if ($cd >= 2**24) {
-	    @cv = (2, $r, $g, $b);
-	}
-	elsif ($cd >= 256) {
-	    @cv = (5, Convert::Color::RGB8->new($r, $g, $b)->as_xterm->index);
-	}
-	elsif ($cd >= 16) {
-	    @cv = Convert::Color::RGB8->new($r, $g, $b)->as_xterm_16->index;
-	}
-	elsif ($cd >= 8) {
-	    @cv = Convert::Color::RGB8->new($r, $g, $b)->as_xterm_8->index;
-	}
+    my $bg = $ct =~ /background/;
+    my @cv;
+    if ($cd >= 2**24) {
+	@cv = (2, $r, $g, $b);
+    }
+    elsif ($cd >= 256) {
+	@cv = (5, Convert::Color::RGB8->new($r, $g, $b)->as_xterm->index);
+    }
+    elsif ($cd >= 16) {
+	@cv = Convert::Color::RGB8->new($r, $g, $b)->as_xterm_16->index;
+    }
+    elsif ($cd >= 8) {
+	@cv = Convert::Color::RGB8->new($r, $g, $b)->as_xterm_8->index;
+    }
+    if (ref $self->{ansify_opts}{color_format}) {
+	shift @cv if @cv > 1;
+	$self->{ansify_opts}{color_format}->($bg, @cv);
+    }
+    elsif (@cv > 1) {
+	($bg ? 48 : 38), @cv
+    }
+    elsif (@cv) {
+	(30 + $bg * 10 + int($cv[0]/8) * 60 + $cv[0]%8);
+    }
+    else {
+	return
+    }
+}
+sub _class_to_ansi {
+    my $self = shift;
+    my @class = @_;
+    unless (@class) {
+	my $reset;
+
 	if (ref $self->{ansify_opts}{color_format}) {
-	    shift @cv if @cv > 1;
-	    $self->{ansify_opts}{color_format}->($bg, @cv);
-	}
-	elsif (@cv > 1) {
-	    ($bg ? 48 : 38), @cv
-	}
-	elsif (@cv) {
-	    (30 + $bg * 10 + int($cv[0]/8) * 60 + $cv[0]%8);
-	}
-	else {
-	    return
+	    $reset .= join '', $self->{ansify_opts}{color_format}->();
 	}
+	;
+	$reset .= "\e[$Term::ANSIColor::ATTRIBUTES{reset}m";
+
+	return $reset
     }
-    method _class_to_ansi(@class) {
-	unless (@class) {
-	    my $reset;
 
-	    if (ref $self->{ansify_opts}{color_format}) {
-		$reset .= join '', $self->{ansify_opts}{color_format}->();
-	    };
-	    $reset .= "\e[$Term::ANSIColor::ATTRIBUTES{reset}m";
+    my (@simple, @ext_color);
+    push @simple, $Term::ANSIColor::ATTRIBUTES{reset};
 
-	    return $reset
-	}
+    my %seen;
 
-	my (@simple, @ext_color);
-	push @simple, $Term::ANSIColor::ATTRIBUTES{reset};
+    for my $class (reverse @class) {
+	my $css = $self->{ansify_ccss}{".$class"} // $self->{ansify_css}{".$class"};
 
-	my %seen;
+	push @simple, $Term::ANSIColor::ATTRIBUTES{underline}
+	    if exists $css->{'text-decoration'}  && !$seen{ul}++ && $css->{'text-decoration'} =~ /underline/i;
 
-	for my $class (reverse @class) {
-	    my $css = $self->{ansify_ccss}{".$class"} // $self->{ansify_css}{".$class"};
+	push @simple, $Term::ANSIColor::ATTRIBUTES{bold}
+	    if exists $css->{'font-weight'} && !$seen{b}++ && $css->{'font-weight'} =~ /bold/i;
 
-	    push @simple, $Term::ANSIColor::ATTRIBUTES{underline}
-		if exists $css->{'text-decoration'}  && !$seen{ul}++ && $css->{'text-decoration'} =~ /underline/i;
+	push @simple, $self->{_ansify_italic}
+	    if exists $css->{'font-style'} && !$seen{em}++ && $css->{'font-style'} =~ /italic/i;
 
-	    push @simple, $Term::ANSIColor::ATTRIBUTES{bold}
-		if exists $css->{'font-weight'} && !$seen{b}++ && $css->{'font-weight'} =~ /bold/i;
+	# where to store colour result?
+	my $scf = ref $self->{ansify_opts}{color_format} ? \@ext_color : \@simple;
 
-	    push @simple, $self->{_ansify_italic}
-		if exists $css->{'font-style'} && !$seen{em}++ && $css->{'font-style'} =~ /italic/i;
-
-	    # where to store colour result?
-	    my $scf = ref $self->{ansify_opts}{color_format} ? \@ext_color : \@simple;
-
-	    for my $ct ('color', 'background-color') {
-		if (exists $css->{$ct} && !$seen{$ct}++ && $css->{$ct} =~ /^#([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i) {
-		    my ($r, $g, $b) = map { hex $_ } ($1, $2, $3);
-		    push @$scf, $self->_colour_to_ansi($ct, $r, $g, $b);
-		}
+	for my $ct ('color', 'background-color') {
+	    if (exists $css->{$ct} && !$seen{$ct}++ && $css->{$ct} =~ /^#([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i) {
+		my ($r, $g, $b) = map { hex $_ } ($1, $2, $3);
+		push @$scf, $self->_colour_to_ansi($ct, $r, $g, $b);
 	    }
 	}
-
-	my $format;
-
-	my $simple = join ';', grep { length } @simple;
-	if (length $simple) {
-	    $format .= "\e[${simple}m";
-	}
-	if (@ext_color) {
-	    $format .= join '', @ext_color;
-	}
-
-	$format
     }
-    method _dump_node_ansi($node) {
-	my $ret;
-	for my $st (@{$self->_dump_node_marked($node)}) {
-	    my ($classes, $text) = @$st;
-	    my $format = $self->_class_to_ansi(split ' ', $classes);
-	    $ret .= $format if defined $format;
-	    $ret .= $text;
-	}
-	$ret
+
+    my $format;
+
+    my $simple = join ';', grep { length } @simple;
+    if (length $simple) {
+	$format .= "\e[${simple}m";
     }
-    method ansify_string($string, $mode, %opts) {
-	my %eff_opts = (%ansi_default_opts, %{$self->ansi_opts}, %opts);
-
-	local $self->{htmlize_generate_hyperlinks} = 0;
-	local $self->{mode} = 'css';
-
-	my ($html_node, $css) = $self->htmlize_string($string, $mode);
-	return unless $html_node;
-
-	my $ccss = (ref $eff_opts{css} ? $eff_opts{css}
-			: $eff_opts{css} ? CSS::Tiny->new($eff_opts{css}) : +{}) // +{};
-
-	local $self->{ansify_css} = $css;
-	local $self->{ansify_ccss} = $ccss;
-	local $self->{ansify_opts} = \%eff_opts;
-	local $self->{_ansify_italic} = $Term::ANSIColor::ATTRIBUTES{ $eff_opts{italic_as} } // $eff_opts{italic_as};
-
-	$self->_dump_node_ansi($html_node->firstChild);
+    if (@ext_color) {
+	$format .= join '', @ext_color;
     }
 
+    $format
+}
+sub _dump_node_ansi {
+    my $self = shift;
+    my ($node) = @_;
+    my $ret;
+    for my $st (@{$self->_dump_node_marked($node)}) {
+	my ($classes, $text) = @$st;
+	my $format = $self->_class_to_ansi(split ' ', $classes);
+	$ret .= $format if defined $format;
+	$ret .= $text;
+    }
+    $ret
+}
+sub ansify_string {
+    my $self = shift;
+    my ($string, $mode, %opts) = @_;
+    my %eff_opts = (%ansi_default_opts, %{$self->ansi_opts}, %opts);
+
+    local $self->{htmlize_generate_hyperlinks} = 0;
+    local $self->{mode} = 'css';
+
+    my ($html_node, $css) = $self->htmlize_string($string, $mode);
+    return unless $html_node;
+
+    my $ccss = (ref $eff_opts{css} ? $eff_opts{css}
+		: $eff_opts{css} ? CSS::Tiny->new($eff_opts{css}) : +{}) // +{};
+
+    local $self->{ansify_css} = $css;
+    local $self->{ansify_ccss} = $ccss;
+    local $self->{ansify_opts} = \%eff_opts;
+    local $self->{_ansify_italic} = $Term::ANSIColor::ATTRIBUTES{ $eff_opts{italic_as} } // $eff_opts{italic_as};
+
+    $self->_dump_node_ansi($html_node->firstChild);
+}
+
 =head2 marked_string
 
 run htmlize on the given string, like C<htmlize_string>, but return an
@@ -619,40 +643,44 @@ note, it is B<not> compatible to Text::VimColor!
 
 =cut
 
-    method _dump_node_marked($node) {
-	my @ret;
-	while ($node) {
-	    my (@class, $text);
-	    my $tnode = $node;
-	    while ($tnode->nodeType == XML_ELEMENT_NODE) {
-		push @class, $tnode->getAttribute('class');
-		$tnode = $tnode->firstChild;
-	    }
-
-	    if ($node->nodeType == XML_TEXT_NODE) {
-		$text = $node->data;
-		next unless length $text;
-	    }
-	    else {
-		$text = $node->textContent;
-	    }
-
-	    push @ret, [(join ' ', grep { length } @class) => $text];
+sub _dump_node_marked {
+    my $self = shift;
+    my ($node) = @_;
+    my @ret;
+    while ($node) {
+	my (@class, $text);
+	my $tnode = $node;
+	while ($tnode->nodeType == XML_ELEMENT_NODE) {
+	    push @class, $tnode->getAttribute('class');
+	    $tnode = $tnode->firstChild;
 	}
-	continue {
-	    $node = $node->nextSibling;
+
+	if ($node->nodeType == XML_TEXT_NODE) {
+	    $text = $node->data;
+	    next unless length $text;
+	}
+	else {
+	    $text = $node->textContent;
 	}
-	\@ret
-    }
-    method marked_string($string, $mode) {
-	local $self->{htmlize_generate_hyperlinks} = 0;
-	local $self->{mode} = 'css';
 
-	my $html_node = $self->htmlize_string($string, $mode);
-	return unless $html_node;
-
-    	$self->_dump_node_marked($html_node->firstChild);
+	push @ret, [(join ' ', grep { length } @class) => $text];
     }
+    continue {
+	$node = $node->nextSibling;
+    }
+    \@ret
+}
+sub marked_string {
+    my $self = shift;
+    my ($string, $mode) = @_;
+    local $self->{htmlize_generate_hyperlinks} = 0;
+    local $self->{mode} = 'css';
+
+    my $html_node = $self->htmlize_string($string, $mode);
+    return unless $html_node;
+
+    $self->_dump_node_marked($html_node->firstChild);
+}
 
 =head2 start_server
 
@@ -664,44 +692,45 @@ manually send the kill command to the emacs server.
 
 =cut
 
-    method kill_server {
-	my @cmd = ($self->_client_cmd_args,
-		   -eval => '(kill-emacs)');
-	my ($cout, $cin, $cerr);
-	local $ENV{HOME} = (getpwuid $<)[7] unless $ENV{HOME};
-	local $ENV{TERM} = $self->term_spec;
-	run \@cmd, \$cin, \$cout, \$cerr;
-	$self->{made_server} = 0;
-    }
+sub kill_server {
+    my $self = shift;
+    my @cmd = ($self->_client_cmd_args,
+	       -eval => '(kill-emacs)');
+    my ($cout, $cin, $cerr);
+    local $ENV{HOME} = (getpwuid $<)[7] unless $ENV{HOME};
+    local $ENV{TERM} = $self->term_spec;
+    run \@cmd, \$cin, \$cout, \$cerr;
+    $self->{made_server} = 0;
+}
 
-    method DEMOLISH {
-	$self->kill_server if $self->_kill_server && $self->{made_server}
-    }
-};
+sub DEMOLISH {
+    my ($self, $in_global_destruction) = @_;
+    $self->kill_server if $self->_kill_server && $self->{made_server}
+}
 
-package Convert::Color::XTerm8 {
-    my $base = 'Convert::Color::XTerm';
-    if ($base->can('register_color_space')) {
-	our @ISA = $base;
-	__PACKAGE__->register_color_space('xterm_8');
-	__PACKAGE__->register_palette(
-	    enumerate_once => sub {
-		map { __PACKAGE__->new($_) } 0..7
-	    });
-    }
-};
+{ package Convert::Color::XTerm8;
+  my $base = 'Convert::Color::XTerm';
+  if ($base->can('register_color_space')) {
+      our @ISA = $base;
+      __PACKAGE__->register_color_space('xterm_8');
+      __PACKAGE__->register_palette(
+	  enumerate_once => sub {
+	      map { __PACKAGE__->new($_) } 0..7
+	  });
+  }
+}
 
-package Convert::Color::XTerm16 {
-    my $base = 'Convert::Color::XTerm';
-    if ($base->can('register_color_space')) {
-	our @ISA = $base;
-	__PACKAGE__->register_color_space('xterm_16');
-	__PACKAGE__->register_palette(
-	    enumerate_once => sub {
-		map { __PACKAGE__->new($_) } 0..15
-	    });
-    }
-};
+{ package Convert::Color::XTerm16;
+  my $base = 'Convert::Color::XTerm';
+  if ($base->can('register_color_space')) {
+      our @ISA = $base;
+      __PACKAGE__->register_color_space('xterm_16');
+      __PACKAGE__->register_palette(
+	  enumerate_once => sub {
+	      map { __PACKAGE__->new($_) } 0..15
+	  });
+  }
+}
 
 =head1 SEE ALSO
 
@@ -728,4 +757,4 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-    1
+1
